Struct Match

struct Match<'k, 'v, V> { ... }

A successful match consisting of the registered value and URL parameters, returned by Router::at.

Fields

value: V

The value stored under the matched node.

params: Params<'k, 'v>

The route parameters. See parameters for more details.

Implementations

impl<'k, 'v, V> Freeze for Match<'k, 'v, V>

impl<'k, 'v, V> RefUnwindSafe for Match<'k, 'v, V>

impl<'k, 'v, V> Send for Match<'k, 'v, V>

impl<'k, 'v, V> Sync for Match<'k, 'v, V>

impl<'k, 'v, V> Unpin for Match<'k, 'v, V>

impl<'k, 'v, V> UnsafeUnpin for Match<'k, 'v, V>

impl<'k, 'v, V> UnwindSafe for Match<'k, 'v, V>

impl<'k, 'v, V: $crate::fmt::Debug> Debug for Match<'k, 'v, V>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for Match<'k, 'v, V>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Match<'k, 'v, V>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Match<'k, 'v, V>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Match<'k, 'v, V>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Match<'k, 'v, V>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Match<'k, 'v, V>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Match<'k, 'v, V>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>